@@ -53,7 +53,7 @@ use vars qw( $VERSION @EXPORT_OK %EXPORT_TAGS );
 use base qw( Exporter DynaLoader );
 
 BEGIN {
-  $VERSION = "2.02";
+  $VERSION = "2.03";
   bootstrap Net::BGPdump $VERSION;
   __PACKAGE__->log_to_stderr(1);
 }
@@ -127,17 +127,12 @@ my %All;
 ###
 
 use overload
-  '<>'     => \&read,
+  '<>'     => \&read_msg,
   fallback => 1;
 
 my %Defaults = (
-  type            => -1,
-  subtype         => -1,
-  msgtype         => -1,
-  exclude_type    => -1,
-  exclude_subtype => -1,
-  exclude_msgtype => -1,
-  ipv6            => -1,
+  ipv4            => 1,
+  ipv6            => 1,
   begin_time      => 0,
   end_time        => 0,
 );
@@ -154,6 +149,17 @@ sub open {
     croak "unknown option '$k'" unless defined $opt{$k};
     $opt{$k} = $arg{$k} if defined $arg{$k};
   }
+  if ($opt{ipv6}) {
+    if ($opt{ipv4}) {
+      $opt{ipv6_flag} = 0;
+    }
+    else {
+      $opt{ipv6_flag} = 1;
+    }
+  }
+  else {
+    $opt{ipv6_flag} = -1;
+  }
   my $self = $class->_open($file);
   $Attr{$self} = \%opt;
   $self;
@@ -170,13 +176,7 @@ sub read {
   my $attr = $Attr{$self};
   my $entry = filter_read(
     $self,
-    $attr->{type},
-    $attr->{subtype},
-    $attr->{msgtype},
-    $attr->{exclude_type},
-    $attr->{exclude_subtype},
-    $attr->{exclude_msgtype},
-    $attr->{ipv6},
+    $attr->{ipv6_flag},
     $attr->{begin_time},
     $attr->{end_time},
   );
@@ -188,7 +188,7 @@ sub read_msg {
   my $attr = $Attr{$self};
   my $entry = filter_message_read(
     $self,
-    $attr->{ipv6},
+    $attr->{ipv6_flag},
     $attr->{begin_time},
     $attr->{end_time},
   );
@@ -211,13 +211,14 @@ Net::BGPdump - Perl extension for libBGPdump
 
   use Net::BGPdump qw( :all );
 
-  my $io = Net::BGPdump->open($file, msgtype => BGP_MSG_UPDATE);
+  my $io = Net::BGPdump->open($file);
 
   while (<$io>) {
+    next unless $_->{type_id} == BGP_MSG_UPDATE;
     print "TIME: $_->{time}\n";
     print "TYPE: $_->{type}\n";
-    printf("FROM: %s AS%d\n", $_->{from_addr}, $_->{from_as});
-    printf("TO: %s AS%d\n", $_->{to_addr}, $_->{to_as});
+    printf("FROM: %s AS%d\n", $_->{peer_addr}, $_->{peer_as});
+    printf("TO: %s AS%d\n", $_->{dest_addr}, $_->{dest_as});
     print "ORIGIN: $_->{origin}\n";
     print "ASPATH: $_->{as_path}\n";
     print "NEXT_HOP: $_->{next_hop}\n";
@@ -238,7 +239,8 @@ Net::BGPdump - Perl extension for libBGPdump
 =head1 DESCRIPTION
 
 Net::PGPDump is a perl extension for libBGPdump, a C library designed to
-help with analyzing dump files produced by Zebra/Quagga or MRT.
+help with analyzing dump files produced by Zebra/Quagga or MRT. These
+include update files as well as table dump (or RIB) files.
 
 The bgpdump library can be L<found here:|https://bitbucket.org/ripencc/bgpdump/>
 
@@ -260,70 +262,13 @@ or individually.
 
 =over
 
-=item type
-
-=item exclude_type
-
-Include or exclude records of the following types:
-
-  BGPDUMP_TYPE_MRTD_BGP
-  BGPDUMP_TYPE_MRTD_TABLE_DUMP
-  BGPDUMP_TYPE_TABLE_DUMP_V2
-  BGPDUMP_TYPE_ZEBRA_BGP
-
-=item subtype
-
-=item exclude_subtype
-
-Include or exclude records of the following subtypes:
-
-  BGPDUMP_SUBTYPE_MRTD_BGP_NULL
-  BGPDUMP_SUBTYPE_MRTD_BGP_UPDATE
-  BGPDUMP_SUBTYPE_MRTD_BGP_PREFUPDATE
-  BGPDUMP_SUBTYPE_MRTD_BGP_STATE_CHANGE
-  BGPDUMP_SUBTYPE_MRTD_BGP_SYNC
-  BGPDUMP_SUBTYPE_MRTD_BGP_OPEN
-  BGPDUMP_SUBTYPE_MRTD_BGP_NOTIFICATION
-  BGPDUMP_SUBTYPE_MRTD_BGP_KEEPALIVE
-  BGPDUMP_SUBTYPE_MRTD_BGP_ROUT_REFRESH
-
-  BGPDUMP_SUBTYPE_MRTD_TABLE_DUMP_AFI_IP6
-  BGPDUMP_SUBTYPE_MRTD_TABLE_DUMP_AFI_IP6_32BIT_AS
-  BGPDUMP_SUBTYPE_MRTD_TABLE_DUMP_AFI_IP
-  BGPDUMP_SUBTYPE_MRTD_TABLE_DUMP_AFI_IP_32BIT_AS
-
-  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_PEER_INDEX_TABLE
-  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_RIB_IPV4_UNICAST
-  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_RIB_IPV4_MULTICAST
-  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_RIB_IPV6_UNICAST
-  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_RIB_IPV6_MULTICAST
-  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_RIB_GENERIC
-  BGPDUMP_PEERTYPE_TABLE_DUMP_V2_AFI_IP
-  BGPDUMP_PEERTYPE_TABLE_DUMP_V2_AFI_IP6
-  BGPDUMP_PEERTYPE_TABLE_DUMP_V2_AS2
-  BGPDUMP_PEERTYPE_TABLE_DUMP_V2_AS4
-
-  BGPDUMP_SUBTYPE_ZEBRA_BGP_MESSAGE
-  BGPDUMP_SUBTYPE_ZEBRA_BGP_MESSAGE_AS4
-  BGPDUMP_SUBTYPE_ZEBRA_BGP_STATE_CHANGE
-  BGPDUMP_SUBTYPE_ZEBRA_BGP_STATE_CHANGE_AS4
-
-=item msgtype
-
-=item exclude_msgtype
-
-Include or exclude messages of the following types:
-
-  BGP_MSG_UPDATE
-  BGP_MSG_OPEN
-  BGP_MSG_NOTIFY
-  BGP_MSG_KEEPALIVE
-  BGP_MSG_ROUTE_REFRESH_01
-  BGP_MSG_ROUTE_REFRESH
-
 =item ipv6
 
-Include or exclude records involving IPv6 using 1 or 0, respectively.
+Include or exclude records involving IPv6 (default: 1)
+
+=item ipv4
+
+Include or exclude records involving IPv4 (default: 1)
 
 =item begin_time
 
@@ -344,7 +289,7 @@ Close the C<Net::BGPdump> IO object.
 =item read()
 
 Return the next record as a hash reference. Records are possibly subject
-to filtering as specified in the C<open()> constructor.
+to filtering on ipv6 or time as specified in the C<open()> constructor.
 
 =item read_msg()
 
@@ -386,10 +331,60 @@ Return the number of records successfully poarsed so far.
 
 =head1 OPERATORS
 
-IO objects can be used as filehandles, so C<E<lt>$ioE<gt>> works as expected.
+IO objects can be used as filehandles, so C<E<lt>$ioE<gt>> works as
+though C<read_msg()> was called.
 
 =head1 ADDITIONAL CONSTANTS
 
+Record types:
+
+  BGPDUMP_TYPE_MRTD_BGP
+  BGPDUMP_TYPE_MRTD_TABLE_DUMP
+  BGPDUMP_TYPE_TABLE_DUMP_V2
+  BGPDUMP_TYPE_ZEBRA_BGP
+
+Record subtypes:
+
+  BGPDUMP_SUBTYPE_MRTD_BGP_NULL
+  BGPDUMP_SUBTYPE_MRTD_BGP_UPDATE
+  BGPDUMP_SUBTYPE_MRTD_BGP_PREFUPDATE
+  BGPDUMP_SUBTYPE_MRTD_BGP_STATE_CHANGE
+  BGPDUMP_SUBTYPE_MRTD_BGP_SYNC
+  BGPDUMP_SUBTYPE_MRTD_BGP_OPEN
+  BGPDUMP_SUBTYPE_MRTD_BGP_NOTIFICATION
+  BGPDUMP_SUBTYPE_MRTD_BGP_KEEPALIVE
+  BGPDUMP_SUBTYPE_MRTD_BGP_ROUT_REFRESH
+
+  BGPDUMP_SUBTYPE_MRTD_TABLE_DUMP_AFI_IP6
+  BGPDUMP_SUBTYPE_MRTD_TABLE_DUMP_AFI_IP6_32BIT_AS
+  BGPDUMP_SUBTYPE_MRTD_TABLE_DUMP_AFI_IP
+  BGPDUMP_SUBTYPE_MRTD_TABLE_DUMP_AFI_IP_32BIT_AS
+
+  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_PEER_INDEX_TABLE
+  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_RIB_IPV4_UNICAST
+  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_RIB_IPV4_MULTICAST
+  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_RIB_IPV6_UNICAST
+  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_RIB_IPV6_MULTICAST
+  BGPDUMP_SUBTYPE_TABLE_DUMP_V2_RIB_GENERIC
+  BGPDUMP_PEERTYPE_TABLE_DUMP_V2_AFI_IP
+  BGPDUMP_PEERTYPE_TABLE_DUMP_V2_AFI_IP6
+  BGPDUMP_PEERTYPE_TABLE_DUMP_V2_AS2
+  BGPDUMP_PEERTYPE_TABLE_DUMP_V2_AS4
+
+  BGPDUMP_SUBTYPE_ZEBRA_BGP_MESSAGE
+  BGPDUMP_SUBTYPE_ZEBRA_BGP_MESSAGE_AS4
+  BGPDUMP_SUBTYPE_ZEBRA_BGP_STATE_CHANGE
+  BGPDUMP_SUBTYPE_ZEBRA_BGP_STATE_CHANGE_AS4
+
+Message types:
+
+  BGP_MSG_UPDATE
+  BGP_MSG_OPEN
+  BGP_MSG_NOTIFY
+  BGP_MSG_KEEPALIVE
+  BGP_MSG_ROUTE_REFRESH_01
+  BGP_MSG_ROUTE_REFRESH
+
 The following constants can also be exported:
 
   BGP_STATE_IDLE
@@ -415,7 +410,7 @@ The following constants can also be exported:
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2015 by Carnegie Mellon University
+Copyright (C) 2015-2016 by Carnegie Mellon University
 
 Use of the Net-BGPdump library and related source code is subject to the
 terms of the following licenses:
